@@ -87,6 +87,7 @@ Out of the box implementation of the Construct without any override will set the
 
 * Configure least privilege access IAM role for Lambda function
 * Enable reusing connections with Keep-Alive for NodeJs Lambda function
+* Enable X-Ray Tracing
 
 ## Architecture
 
@@ -104,8 +105,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -128,7 +129,7 @@ class KinesisStreamsToLambda(
     def __init__(
         self,
         scope: aws_cdk.core.Construct,
-        id: str,
+        id: builtins.str,
         *,
         event_source_props: typing.Any = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
@@ -159,17 +160,17 @@ class KinesisStreamsToLambda(
 
         jsii.create(KinesisStreamsToLambda, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="kinesisStream")
     def kinesis_stream(self) -> aws_cdk.aws_kinesis.Stream:
         return jsii.get(self, "kinesisStream")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="kinesisStreamRole")
     def kinesis_stream_role(self) -> aws_cdk.aws_iam.Role:
         return jsii.get(self, "kinesisStreamRole")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return jsii.get(self, "lambdaFunction")
@@ -205,7 +206,7 @@ class KinesisStreamsToLambdaProps:
             kinesis_stream_props = aws_cdk.aws_kinesis.StreamProps(**kinesis_stream_props)
         if isinstance(lambda_function_props, dict):
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if event_source_props is not None:
             self._values["event_source_props"] = event_source_props
         if existing_lambda_obj is not None:
@@ -222,7 +223,8 @@ class KinesisStreamsToLambdaProps:
         default
         :default: - Default props are used.
         """
-        return self._values.get("event_source_props")
+        result = self._values.get("event_source_props")
+        return result
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
@@ -231,7 +233,8 @@ class KinesisStreamsToLambdaProps:
         default
         :default: - None
         """
-        return self._values.get("existing_lambda_obj")
+        result = self._values.get("existing_lambda_obj")
+        return result
 
     @builtins.property
     def kinesis_stream_props(self) -> typing.Optional[aws_cdk.aws_kinesis.StreamProps]:
@@ -240,7 +243,8 @@ class KinesisStreamsToLambdaProps:
         default
         :default: - Default props are used.
         """
-        return self._values.get("kinesis_stream_props")
+        result = self._values.get("kinesis_stream_props")
+        return result
 
     @builtins.property
     def lambda_function_props(
@@ -251,12 +255,13 @@ class KinesisStreamsToLambdaProps:
         default
         :default: - Default props are used.
         """
-        return self._values.get("lambda_function_props")
+        result = self._values.get("lambda_function_props")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
